AccountRegistration class

SIP Account Registration Status

Tracks the registration state of a SIP account with the SIP server.

Source: sdd-account specification Tasks: account-002, account-004

Constructors

AccountRegistration({required bool status, int? code, String? reason, int? expiration, int? retryAfter})
const
AccountRegistration.fromMap(Map<String, dynamic> map)
Create from JSON map
factory

Properties

code int?
SIP status code (200 = OK, 401 = Unauthorized, etc.)
final
expiration int?
Registration expiration time in seconds
final
hashCode int
The hash code for this object.
no setteroverride
isActive bool
Check if registration is active
no setter
isAuthenticationError bool
Check if registration failed due to authentication
no setter
isClientError bool
Check if registration failed due to client error
no setter
isServerError bool
Check if registration failed due to server error
no setter
reason String?
Human-readable reason for the status
final
retryAfter int?
Retry-after hint in seconds (if registration failed)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status bool
Registration status (true = registered, false = not registered)
final
statusText String
Get status text description
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Convert to JSON map
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override