DeviceInfo class

Модель информации об устройстве

Constructors

DeviceInfo({String? deviceId, String? deviceModel, required String osVersion, required String platform, required bool isPhysicalDevice, Map<String, dynamic> additionalInfo = const {}})
DeviceInfo.fromJson(Map<String, dynamic> json)
Создание из JSON
factory

Properties

additionalInfo Map<String, dynamic>
final
deviceId String?
final
deviceModel String?
final
hashCode int
The hash code for this object.
no setteroverride
isPhysicalDevice bool
final
osVersion String
final
platform String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? deviceId, String? deviceModel, String? osVersion, String? platform, bool? isPhysicalDevice, Map<String, dynamic>? additionalInfo}) DeviceInfo
Копирование с изменениями
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Преобразование в JSON
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override