DongleConfig class

Конфигурация донгла (адаптера)

Constructors

DongleConfig({required DongleInterfaceType interfaceType, DongleType? dongleType, bool enableInversion = true, int? outputVolume, int? sampleRate, int? bitDepth, bool autoDetectType = true})
const
DongleConfig.fromJson(Map<String, dynamic> json)
Десериализация из JSON
factory

Properties

autoDetectType bool
Автоматическое определение типа
final
bitDepth int?
Разрядность (бит)
final
dongleType DongleType?
Тип схемы донгла
final
enableInversion bool
Инверсия правого канала (для differential signaling)
final
hashCode int
The hash code for this object.
no setterinherited
interfaceType DongleInterfaceType
Тип интерфейса
final
outputVolume int?
Уровень выходного сигнала (0-100)
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int?
Частота дискретизации (Гц)
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({DongleInterfaceType? interfaceType, DongleType? dongleType, bool? enableInversion, int? outputVolume, int? sampleRate, int? bitDepth, bool? autoDetectType}) DongleConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Сериализация в JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultConfig → const DongleConfig
Конфигурация по умолчанию
trrsConfig → const DongleConfig
Конфигурация для TRRS
usbAccessoryConfig → const DongleConfig
Конфигурация для USB-C Audio Accessory
usbDacConfig → const DongleConfig
Конфигурация для USB-C with DAC