ResistanceMeasurementResult class

Результат измерения сопротивления

Constructors

ResistanceMeasurementResult({required bool success, required ResistanceMeasurements measurements, String? error})
const
ResistanceMeasurementResult.fromJson(Map<String, dynamic> json)
Десериализация из JSON
factory

Properties

error String?
Сообщение об ошибке
final
hashCode int
The hash code for this object.
no setterinherited
measurements ResistanceMeasurements
Измерения
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
Успешно ли измерение
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Сериализация в JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited