SipCallModel class

SIP Call model

Constructors

SipCallModel({required String id, required String accountId, required String number, String direction = 'outgoing', String state = 'initiated', String? startTime, String? connectTime, String? endTime, bool isMuted = false, bool isOnHold = false, bool isSpeaker = false, String? transferTarget, String? redirectTarget, String? callerName})
const
SipCallModel.fromEntity(SipCall entity)
Create from entity
factory
SipCallModel.fromJson(Map<String, dynamic> json)
Create from JSON
factory

Properties

accountId String
final
callerName String?
final
connectTime String?
final
direction String
final
endTime String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isMuted bool
final
isOnHold bool
final
isSpeaker bool
final
number String
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
redirectTarget String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime String?
final
state String
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
transferTarget String?
final

Methods

copyWith({String? id, String? accountId, String? number, String? direction, String? state, String? startTime, String? connectTime, String? endTime, bool? isMuted, bool? isOnHold, bool? isSpeaker, String? transferTarget, String? redirectTarget, String? callerName}) SipCallModel
Create a copy with updated fields
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEntity() SipCall
Convert to entity
toJson() Map<String, dynamic>
Convert to JSON
toString() String
A string representation of this object.

Operators

operator ==(Object other) bool
The equality operator.
inherited