SmppDeliveryReceipt class

Constructors

SmppDeliveryReceipt({required String messageId, required String sourceAddress, required String destinationAddress, required DateTime submitDate, required DateTime doneDate, required SmppMessageStatus status, String? errorCode, String? text})
SmppDeliveryReceipt.fromJson(Map<String, dynamic> json)
factory

Properties

destinationAddress String
final
doneDate DateTime
final
errorCode String?
final
hashCode int
The hash code for this object.
no setterinherited
messageId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceAddress String
final
status SmppMessageStatus
final
submitDate DateTime
final
text String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited