TimeoutException class

Timeout-specific network exception

Inheritance

Constructors

TimeoutException({required String message, String? code, dynamic originalError, StackTrace? stackTrace, String? endpoint, Duration? duration})
const

Properties

code String?
finalinherited
duration Duration?
final
endpoint String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
originalError → dynamic
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
finalinherited
statusCode int?
finalinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited