Account class
Constructors
-
Account({required int id, required String uri, required String name, required String username, required String domain, required String password, String? proxy, String? transport, String? contactParams, String? contactUriParams, String? regServer, int? regTimeout, String? regContactParams, Map<
String, dynamic> ? regHeaders, AccountRegistration registration = const AccountRegistration(status: false)}) -
const
-
Account.fromMap(Map<
String, dynamic> map) -
Create from JSON map
factory
Properties
- contactParams → String?
-
Contact parameters for registration
final
- contactUriParams → String?
-
Contact URI parameters
final
- domain → String
-
SIP domain/server
final
- effectiveRegServer → String
-
Get the registration server (falls back to domain)
no setter
- effectiveTransport → String
-
Get transport protocol (defaults to TCP)
no setter
- fullUri → String
-
Get the full SIP URI with username and domain
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
Unique account identifier
final
- isRegistered → bool
-
Check if account is currently registered
no setter
- name → String
-
Display name for the account
final
- password → String
-
SIP password for authentication
final
- proxy → String?
-
Proxy server (optional)
final
- regContactParams → String?
-
Registration contact parameters
final
-
regHeaders
→ Map<
String, dynamic> ? -
Custom headers for registration
final
- registration → AccountRegistration
-
Current registration status
final
- regServer → String?
-
Registration server (if different from domain)
final
- regTimeout → int?
-
Registration timeout in seconds (default: 3600)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transport → String?
-
Transport protocol (TCP, UDP, TLS)
final
- uri → String
-
SIP URI (e.g., sip:username@domain)
final
- username → String
-
SIP username for authentication
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Convert to JSON map
-
toString(
) → String -
A string representation of this object.
override
-
withRegistration(
AccountRegistration newRegistration) → Account - Create a copy with updated registration status
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override