DongleStatus class
Статус донгла (адаптера)
Constructors
- DongleStatus({required bool connected, required DongleInterfaceType interfaceType, DongleType? dongleType, int? measuredResistanceMic, int? measuredResistanceLeft, int? measuredResistanceRight, QualityLevel quality = QualityLevel.poor, String? statusMessage})
-
const
-
DongleStatus.fromJson(Map<
String, dynamic> json) -
Десериализация из JSON
factory
Properties
- connected → bool
-
Подключён ли донгл
final
- dongleType → DongleType?
-
Тип схемы (определяется по сопротивлению)
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- interfaceType → DongleInterfaceType
-
Тип интерфейса
final
- measuredResistanceLeft → int?
-
Измеренное сопротивление L→GND (омы)
final
- measuredResistanceMic → int?
-
Измеренное сопротивление GND→MIC (омы)
final
- measuredResistanceRight → int?
-
Измеренное сопротивление R→GND (омы)
final
- quality → QualityLevel
-
Уровень качества
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusMessage → String?
-
Сообщение об ошибке или статусе
final
Methods
-
copyWith(
{bool? connected, DongleInterfaceType? interfaceType, DongleType? dongleType, int? measuredResistanceMic, int? measuredResistanceLeft, int? measuredResistanceRight, QualityLevel? quality, String? statusMessage}) → DongleStatus -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Сериализация в JSON
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
calculateQuality(
{required DongleInterfaceType interfaceType, DongleType? dongleType}) → QualityLevel - Получить качество на основе типа интерфейса и типа донгла