LocalDataSource class
Локальный источник данных Direct access to SharedPreferences without presentation layer dependencies
Constructors
- LocalDataSource(SharedPreferences _prefs)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAllData(
) → Future< bool> - Очистка всех данных
-
containsKey(
String key) → bool - Проверка существования ключа
-
deleteData(
String key) → Future< bool> - Удаление данных
-
getData(
String key) → Map< String, dynamic> ? - Получение данных
-
getKeys(
) → List< String> - Получение всех ключей
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveData(
String key, dynamic data) → Future< bool> - Сохранение данных
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited